@@ -174,7 +174,7 @@ hd_applications_menu_init (HDApplicationsMenu *button)
   gtk_widget_show_all (priv->button);
 
   hdwm = hd_wm_get_singleton ();
-  hd_wm_set_all_menu_button (hdwm, priv->button);
+  hd_wm_set_all_menu_button (hdwm, G_OBJECT (priv->button));
 
   g_signal_connect (G_OBJECT (priv->button), 
 		    "toggled",
@@ -218,7 +218,7 @@ hd_applications_menu_has_focus (HildonDesktopPopupMenu *menu)
   {
     GtkWidget *item = (GtkWidget *) i->data;
 
-    if (GTK_WIDGET_HAS_FOCUS (item))
+    if (gtk_widget_is_focus (item))
       return TRUE;
   }
 
@@ -242,7 +242,7 @@ hd_applications_menu_key_press (GtkWidget *menu,
 			        HDApplicationsMenu *button)
 {
   HDWM *hdwm = hd_wm_get_singleton ();
-  
+
   if (event->keyval == GDK_Left    ||
       event->keyval == GDK_KP_Left ||
       event->keyval == GDK_Escape)
@@ -303,6 +303,10 @@ hd_applications_menu_key_press (GtkWidget *menu,
       
       return TRUE;
     }
+    else if (hd_applications_menu_has_focus (button->priv->menu_applications))
+    {
+      return gtk_widget_event (GTK_WIDGET (button->priv->menu_applications), (GdkEvent *) event);
+    }
   }
   else
   {
@@ -557,12 +561,9 @@ hd_applications_menu_get_items (HDApplicationsMenu *button,
 
   if (model == NULL)
   {
-    GtkTreeIter fiter;
-
     model = get_menu_contents ();
     
-    if (!gtk_tree_model_get_iter_first (model, &fiter) ||
-        !gtk_tree_model_iter_children (model, iter, &fiter))
+    if (!gtk_tree_model_get_iter_first (model, iter))
     {
       g_object_unref (G_OBJECT (model));
 
@@ -803,7 +804,11 @@ hd_applications_menu_create_menu (HDApplicationsMenu *button)
 
   gtk_widget_set_size_request (GTK_WIDGET (popup_window), 650, 480);
 
-  hildon_desktop_popup_window_attach_widget (popup_window, button->priv->button);
+  /* We don't attach the widget because if we do it, we cannot be on top of 
+   * virtual keyboard. Anyway it should be transient to button->priv->button
+   */
+  
+  hildon_desktop_popup_window_attach_widget (popup_window, NULL);
   
   button->priv->menu_categories =
     HILDON_DESKTOP_POPUP_MENU (g_object_new (HILDON_DESKTOP_TYPE_POPUP_MENU,
