@@ -139,16 +139,16 @@ enum
 };
 
 static void 
-hn_app_switcher_add_info_cb (HDWM *hdwm, HDEntryInfo *entry_info, gpointer data);
+hn_app_switcher_add_info_cb (HDWM *hdwm, HDWMEntryInfo *entry_info, gpointer data);
 
 static void 
-hn_app_switcher_remove_info_cb (HDWM *hdwm, gboolean removed_app, HDEntryInfo *entry_info, gpointer data);
+hn_app_switcher_remove_info_cb (HDWM *hdwm, gboolean removed_app, HDWMEntryInfo *entry_info, gpointer data);
 
 static void 
-hn_app_switcher_changed_info_cb (HDWM *hdwm, HDEntryInfo *entry_info, gpointer data);
+hn_app_switcher_changed_info_cb (HDWM *hdwm, HDWMEntryInfo *entry_info, gpointer data);
 
 static void 
-hn_app_switcher_changed_stack_cb (HDWM *hdwm, HDEntryInfo *entry_info, gpointer data);
+hn_app_switcher_changed_stack_cb (HDWM *hdwm, HDWMEntryInfo *entry_info, gpointer data);
 
 static void 
 hn_app_switcher_orientation_changed_cb (HNAppSwitcher *app_switcher);
@@ -160,7 +160,7 @@ static void
 hn_app_switcher_get_property (GObject *object, guint prop_id, GValue *value, GParamSpec *pspec);
 
 static void
-refresh_app_button (HNAppSwitcher *app_switcher, HDEntryInfo *entry, gint pos);
+refresh_app_button (HNAppSwitcher *app_switcher, HDWMEntryInfo *entry, gint pos);
 
 static void
 queue_refresh_buttons (HNAppSwitcher *app_switcher);
@@ -208,10 +208,9 @@ struct _HNAppSwitcherPrivate
   
   /* pointer location */
   guint pointer_on_button : 1;
-  guint is_thumbable : 1;
-  gboolean force_thumb : 1;
-  guint was_thumbable : 1;
   gboolean is_fullscreen;
+ 
+  guint orientation_changed : 1; 
 
   guint menu_button_timeout;
 
@@ -267,7 +266,7 @@ app_button_toggled_cb (GtkToggleButton *toggle,
   gboolean is_active = gtk_toggle_button_get_active (toggle);
   gboolean is_inconsistent = gtk_toggle_button_get_inconsistent (toggle);
   gchar *name,*name_pressed;
-  static gint i=0;
+  
   name =
    g_strdup_printf (AS_BUTTON_NAME,pos+1);
 
@@ -287,11 +286,10 @@ app_button_toggled_cb (GtkToggleButton *toggle,
   g_free (name);
   g_free (name_pressed);
 
-  g_debug ("%i setting button (pos=%d) (inconsistent='<%s>', active='<%s>') name: %s",
-	   i,pos,
-	   is_inconsistent ? "true" : "false",
-	   is_active ? "true" : "false",
-	   gtk_widget_get_name (widget));
+  hd_wm_debug ("setting button (pos=%d) (inconsistent='<%s>', active='<%s>') name: %s",
+	       pos, is_inconsistent ? "true" : "false",
+	       is_active ? "true" : "false",
+	       gtk_widget_get_name (widget));
 }
 
 static void 
@@ -299,7 +297,7 @@ hn_app_switcher_orientation_changed_cb (HNAppSwitcher *app_switcher)
 {
   GList *children = NULL, *iter;
 
-  g_debug ("orientation_changed");
+  app_switcher->priv->orientation_changed = TRUE;
   
   if (GTK_IS_CONTAINER (app_switcher->box))
     children = 
@@ -354,7 +352,7 @@ create_app_button (HNAppSwitcher *app_switcher,
   name = 
     g_strdup_printf (AS_BUTTON_NAME,pos+1);
   
-  g_debug ("Creating app button at pos %d (name %s)", pos, name);
+  hd_wm_debug ("Creating app button at pos %d (name %s)", pos, name);
  
   retval = hn_app_button_new (NULL);
 
@@ -395,7 +393,7 @@ hn_app_switcher_build (HNAppSwitcher *app_switcher)
   gtk_widget_push_composite_child ();
 
   /* most recent applications buttons */
-  g_debug ("Adding buttons");
+  hd_wm_debug ("Adding buttons");
 
   for (i=0;i < app_switcher->priv->nitems;i++)
   {
@@ -520,7 +518,7 @@ hn_app_switcher_show_all (GtkWidget *widget)
   for (i = 0; i < priv->nitems; i++)
   {
     GtkWidget *button = priv->buttons[i];
-    HDEntryInfo *info;
+    HDWMEntryInfo *info;
      
     info = hn_app_button_get_entry_info (HN_APP_BUTTON (button));
     if (info)
@@ -530,7 +528,7 @@ hn_app_switcher_show_all (GtkWidget *widget)
 
 static void
 remove_entry_from_app_button (HNAppSwitcher *app_switcher,
-			      HDEntryInfo   *entry_info)
+			      HDWMEntryInfo   *entry_info)
 {
   HNAppSwitcherPrivate *priv = app_switcher->priv;
   gint pos;
@@ -540,7 +538,7 @@ remove_entry_from_app_button (HNAppSwitcher *app_switcher,
   for (pos = 0; pos < priv->nitems; pos++)
   {
     GtkWidget *button = priv->buttons[pos];
-    HDEntryInfo *e;
+    HDWMEntryInfo *e;
 
     e = hn_app_button_get_entry_info (HN_APP_BUTTON (button));
     if (e == entry_info)
@@ -555,11 +553,11 @@ remove_entry_from_app_button (HNAppSwitcher *app_switcher,
 
 static void
 refresh_app_button (HNAppSwitcher *app_switcher,
-                    HDEntryInfo   *entry,
+                    HDWMEntryInfo *entry,
                     gint           pos)
 {
   HNAppSwitcherPrivate *priv = app_switcher->priv;
-  const GList          *l, *children = hd_entry_info_get_children(entry);
+  const GList          *l, *children = hd_wm_entry_info_get_children (entry);
   gboolean              urgent = FALSE;
   HNAppButton          *app_button = HN_APP_BUTTON (priv->buttons[pos]);
   gboolean 	       update_icon_geometry;
@@ -570,22 +568,23 @@ refresh_app_button (HNAppSwitcher *app_switcher,
   /* deal with urgency flags */
   for (l = children; l != NULL; l = l->next)
   {
-    if (update_icon_geometry)	    
-      hd_entry_info_set_icon_geometry (l->data,	    
-		      		       GTK_WIDGET (app_button)->allocation.x,
-				       GTK_WIDGET (app_button)->allocation.y,
-				       GTK_WIDGET (app_button)->allocation.width,
-				       GTK_WIDGET (app_button)->allocation.height,
-				       TRUE);
+    HDWMEntryInfo *_info = HD_WM_ENTRY_INFO (l->data);	  
 	  
+    if (update_icon_geometry || app_switcher->priv->orientation_changed)	    
+      hd_wm_window_set_icon_geometry (HD_WM_WINDOW (l->data),	    
+		      		      GTK_WIDGET (app_button)->allocation.x,
+				      GTK_WIDGET (app_button)->allocation.y,
+				      GTK_WIDGET (app_button)->allocation.width,
+				      GTK_WIDGET (app_button)->allocation.height,
+				      TRUE);
     /*
      * If the entry is urgent and the ignore flag is not set, the button
      * should blink
      */
-    if (hd_entry_info_is_urgent(l->data) &&
-        !hd_entry_info_get_ignore_urgent(l->data))
+    if (hd_wm_entry_info_is_urgent (_info) &&
+        !hd_wm_entry_info_get_ignore_urgent (_info))
     {
-      g_debug("Found an urgent button");
+      hd_wm_debug("Found an urgent button");
       urgent = TRUE;
     }
 
@@ -593,13 +592,13 @@ refresh_app_button (HNAppSwitcher *app_switcher,
     * if the info is not urgent, we need to clear any leftover
     * ignore_urgent flag
     */
-    if(!hd_entry_info_is_urgent(l->data) &&
-       hd_entry_info_get_ignore_urgent(l->data))
+    if(!hd_wm_entry_info_is_urgent (_info) &&
+       hd_wm_entry_info_get_ignore_urgent (_info))
     {
-      hd_entry_info_set_ignore_urgent(l->data, FALSE);
+      hd_wm_entry_info_set_ignore_urgent (_info, FALSE);
     }
   }
-
+  
   /* bind the entry info to the widget, so that we can
    * use it later when the user toggles the button
    *
@@ -609,12 +608,12 @@ refresh_app_button (HNAppSwitcher *app_switcher,
   hn_app_button_set_group (app_button, priv->buttons_group);
   priv->buttons_group = hn_app_button_get_group (app_button);
 
-  g_debug ("buttons_group.size := %d",
+  hd_wm_debug ("buttons_group.size := %d",
 	  g_slist_length (priv->buttons_group));
 
   hn_app_button_set_is_blinking (app_button, urgent);
 
-  if (hd_entry_info_is_active (entry))
+  if (hd_wm_entry_info_is_active (entry))
   {
     GtkToggleButton *button;
 
@@ -653,12 +652,12 @@ refresh_buttons (gpointer user_data)
        l != NULL;
        l = l->next, pos++)
   {
-    HDEntryInfo *entry = l->data;
+    HDWMEntryInfo *entry = l->data;
 
     /* we just want the most recently used top-level applications */
-    if (entry->type != HD_ENTRY_WATCHED_APP)
+    if (!HD_WM_IS_APPLICATION (entry))
     {
-      g_debug("Object is not an application");
+      hd_wm_debug("Object is not an application");
       continue;
     }
 
@@ -666,7 +665,7 @@ refresh_buttons (gpointer user_data)
     {	    
       if (active_button < 0 &&
           gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(priv->buttons[pos]))&&
-          !hd_entry_info_is_active (entry))
+          !hd_wm_entry_info_is_active (entry))
       {
           active_button = pos;
       }
@@ -675,12 +674,12 @@ refresh_buttons (gpointer user_data)
     }
     else
     {
-      hd_entry_info_set_icon_geometry (l->data,	    
-		      		       GTK_WIDGET (app_switcher)->allocation.x,
-				       GTK_WIDGET (app_switcher)->allocation.y,
-				       GTK_WIDGET (app_switcher)->allocation.width,
-				       GTK_WIDGET (app_switcher)->allocation.height,
-				       FALSE);
+      hd_wm_window_set_icon_geometry (HD_WM_WINDOW (l->data),	    
+		      		      GTK_WIDGET (app_switcher)->allocation.x,
+				      GTK_WIDGET (app_switcher)->allocation.y,
+				      GTK_WIDGET (app_switcher)->allocation.width,
+				      GTK_WIDGET (app_switcher)->allocation.height,
+				      FALSE);
     }	    
   }
 
@@ -688,7 +687,7 @@ refresh_buttons (gpointer user_data)
   {
     GtkToggleButton *button;
       
-    g_debug ("Unsetting the previously active button %d",
+    hd_wm_debug ("Unsetting the previously active button %d",
              active_button);
 
     button = GTK_TOGGLE_BUTTON (priv->buttons[active_button]);
@@ -708,7 +707,7 @@ refresh_buttons (gpointer user_data)
        l = l->next, ++pos)
   {
     const GList       *k;
-    HDEntryInfo       *child;
+    HDWMEntryInfo       *child,*app = HD_WM_ENTRY_INFO (l->data);
 
     if (pos < priv->nitems)
       continue;
@@ -717,7 +716,7 @@ refresh_buttons (gpointer user_data)
      * we skip the first four apps, which cause blinking of the app buttons,
      * not the menu button.
      */
-    for (k = hd_entry_info_get_children (l->data); k != NULL; k = k->next)
+    for (k = hd_wm_entry_info_get_children (app); k != NULL; k = k->next)
     {
       child = k->data;
 
@@ -725,19 +724,21 @@ refresh_buttons (gpointer user_data)
       * button should blink
       */
       
-      if (hd_entry_info_is_urgent(child) && !hd_entry_info_get_ignore_urgent(child))
+      if (hd_wm_entry_info_is_urgent (child) && !hd_wm_entry_info_get_ignore_urgent (child))
         is_urgent = TRUE;
          
       /*
        * if the info is not urgent, we need to clear any leftover
        * ignore_urgent flag
        */
-      if (!hd_entry_info_is_urgent(child) && hd_entry_info_get_ignore_urgent(child))
-        hd_entry_info_set_ignore_urgent(child, FALSE);
+      if (!hd_wm_entry_info_is_urgent (child) && hd_wm_entry_info_get_ignore_urgent (child))
+        hd_wm_entry_info_set_ignore_urgent (child, FALSE);
        
     }
   }
 
+  app_switcher->priv->orientation_changed = FALSE;
+
   return FALSE;
 }
 
@@ -766,7 +767,7 @@ queue_refresh_buttons (HNAppSwitcher *app_switcher)
  * entry has been added to the applications list.
  */
 static void
-hn_app_switcher_add_info_cb (HDWM *hdwm, HDEntryInfo *entry_info, gpointer data)
+hn_app_switcher_add_info_cb (HDWM *hdwm, HDWMEntryInfo *entry_info, gpointer data)
 {
   HNAppSwitcher *app_switcher = HN_APP_SWITCHER (data);
   HNAppSwitcherPrivate *priv = app_switcher->priv;
@@ -795,12 +796,12 @@ hn_app_switcher_add_info_cb (HDWM *hdwm, HDEntryInfo *entry_info, gpointer data)
 static void
 hn_app_switcher_remove_info_cb (HDWM *hdwm, 
 				gboolean removed_app, 
-				HDEntryInfo *entry_info, 
+				HDWMEntryInfo *entry_info, 
 				gpointer data)
 {
   HNAppSwitcher *app_switcher = HN_APP_SWITCHER (data);
   HNAppSwitcherPrivate *priv = app_switcher->priv;
-  HDEntryInfo *info_parent = hd_entry_info_get_parent(entry_info);
+  HDWMEntryInfo *info_parent = hd_wm_entry_info_get_parent(entry_info);
   
   /* Play a sound */
   if (hn_as_sound_play_sample (priv->esd_socket, priv->end_sample) == -1)
@@ -825,11 +826,11 @@ hn_app_switcher_remove_info_cb (HDWM *hdwm,
  * NB: entry_info can be NULL for global update
  */
 static void
-hn_app_switcher_changed_info_cb (HDWM *hdwm, HDEntryInfo *entry_info, gpointer data)
+hn_app_switcher_changed_info_cb (HDWM *hdwm, HDWMEntryInfo *entry_info, gpointer data)
 {
   HNAppSwitcher        *app_switcher = HN_APP_SWITCHER (data);
   HNAppSwitcherPrivate *priv = app_switcher->priv;
-  g_debug ("In hn_app_switcher_real_changed_info");
+  hd_wm_debug ("In hn_app_switcher_real_changed_info");
 
   /* all changes have potential impact on the the main menu; app menus are
    * created on the fly, so we do not have to worry about menu changes there
@@ -839,22 +840,22 @@ hn_app_switcher_changed_info_cb (HDWM *hdwm, HDEntryInfo *entry_info, gpointer d
    * If we are given an entry info and it of the app type, we just need to
    * update at most one button
    */
-  if (entry_info && entry_info->type == HD_ENTRY_WATCHED_APP)
+  if (entry_info && HD_WM_IS_APPLICATION (entry_info))
   {
     gint                  pos;
     GList *               l;
 
-    g_debug ("HDEntryInfo present and of type WATCHED_APP");
+    hd_wm_debug ("HDEntryInfo present and of type APPLICATION");
       
     for (l = hd_wm_get_applications (hdwm), pos = 0;
          l != NULL && pos < priv->nitems;
          l = l->next, pos++)
     {
-      HDEntryInfo *entry = l->data;
+      HDWMEntryInfo *entry = l->data;
           
-      if (entry->type != HD_ENTRY_WATCHED_APP)
+      if (!HD_WM_IS_APPLICATION (entry))
       {
-        g_debug("Object is not an application");
+        hd_wm_debug("Object is not an application");
         continue;
       }
 
@@ -874,15 +875,14 @@ hn_app_switcher_changed_info_cb (HDWM *hdwm, HDEntryInfo *entry_info, gpointer d
      * we already dealt with, child changes affect the blinking of the
      * associated buttons
      */
-    HDEntryInfo *parent;
+    HDWMEntryInfo *parent;
     GtkWidget   *button = NULL;
     GList       *l;
     gint         pos;
       
-    g_return_if_fail (entry_info->type != HD_ENTRY_INVALID);
-    g_debug ("HDEntryInfo present, with child entry");
+    hd_wm_debug ("HDEntryInfo present, with child entry");
 
-    parent = hd_entry_info_get_parent (entry_info);
+    parent = hd_wm_entry_info_get_parent (entry_info);
 
     if (!parent)
     {
@@ -894,8 +894,8 @@ hn_app_switcher_changed_info_cb (HDWM *hdwm, HDEntryInfo *entry_info, gpointer d
      * causing the button to blink, and will not cause the button to blink,
      * so we do not need to update the buttons
      */
-    if (hd_entry_info_is_urgent (entry_info) &&
-        hd_entry_info_get_ignore_urgent (entry_info))
+    if (hd_wm_entry_info_is_urgent (entry_info) &&
+        hd_wm_entry_info_get_ignore_urgent (entry_info))
     {
       return;
     }
@@ -905,10 +905,10 @@ hn_app_switcher_changed_info_cb (HDWM *hdwm, HDEntryInfo *entry_info, gpointer d
      * button to blink (it was being ingored), so we do not need to update
      * the button.
      */
-    if (!hd_entry_info_is_urgent (entry_info) &&
-        hd_entry_info_get_ignore_urgent (entry_info))
+    if (!hd_wm_entry_info_is_urgent (entry_info) &&
+        hd_wm_entry_info_get_ignore_urgent (entry_info))
     {
-      hd_entry_info_set_ignore_urgent (entry_info, FALSE);
+      hd_wm_entry_info_set_ignore_urgent (entry_info, FALSE);
       return;
     }
 
@@ -919,12 +919,12 @@ hn_app_switcher_changed_info_cb (HDWM *hdwm, HDEntryInfo *entry_info, gpointer d
          l != NULL && pos < priv->nitems;
          l = l->next, pos++)
     {
-      HDEntryInfo *entry = l->data;
+      HDWMEntryInfo *entry = l->data;
       
       /* we just want the most recently used top-level applications */
-      if (entry->type != HD_ENTRY_WATCHED_APP)
+      if (!HD_WM_IS_APPLICATION (entry))
       {
-        g_debug("Object is not an application");
+        hd_wm_debug("Object is not an application");
         continue;
       }
 
@@ -937,15 +937,15 @@ hn_app_switcher_changed_info_cb (HDWM *hdwm, HDEntryInfo *entry_info, gpointer d
 
     if (button)
     {
-      g_debug ("Force the button's icon to update itself");
+      hd_wm_debug ("Force the button's icon to update itself");
       hn_app_button_force_update_icon (HN_APP_BUTTON (button));
     }
 
       /* if the current info is urgent and not to be ignored, we know the app
        * button should blink; make sure it does
        */
-    if (hd_entry_info_is_urgent (entry_info) &&
-        !hd_entry_info_get_ignore_urgent (entry_info))
+    if (hd_wm_entry_info_is_urgent (entry_info) &&
+        !hd_wm_entry_info_get_ignore_urgent (entry_info))
     {
       if (button)
       {
@@ -961,8 +961,8 @@ hn_app_switcher_changed_info_cb (HDWM *hdwm, HDEntryInfo *entry_info, gpointer d
      * associated button is not blinking, we know that it was not urgent
      * previously, so we do not need to update the button
      */
-    if (!hd_entry_info_is_urgent (entry_info) &&
-        !hd_entry_info_get_ignore_urgent (entry_info))
+    if (!hd_wm_entry_info_is_urgent (entry_info) &&
+        !hd_wm_entry_info_get_ignore_urgent (entry_info))
     {
       if ((button && !hn_app_button_get_is_blinking (HN_APP_BUTTON (button))))
       {
@@ -978,7 +978,7 @@ hn_app_switcher_changed_info_cb (HDWM *hdwm, HDEntryInfo *entry_info, gpointer d
      */
   }
   
-  g_debug ("Queuing a refresh cycle of the buttons (info: %s)",
+  hd_wm_debug ("Queuing a refresh cycle of the buttons (info: %s)",
            entry_info != NULL ? "yes" : "no");
 
   /* either global update (no entry_info) or a more complicated case that
@@ -992,19 +992,19 @@ hn_app_switcher_changed_info_cb (HDWM *hdwm, HDEntryInfo *entry_info, gpointer d
  * The TN receives notification from MB about window/view being topped. 
  */
 static void
-hn_app_switcher_changed_stack_cb (HDWM *hdwm, HDEntryInfo *entry_info, gpointer data)
+hn_app_switcher_changed_stack_cb (HDWM *hdwm, HDWMEntryInfo *entry_info, gpointer data)
 {
   HNAppSwitcher	       * app_switcher = HN_APP_SWITCHER (data);
   HNAppSwitcherPrivate * priv = app_switcher->priv;
   gint                   pos, active_pos;
   GList                * l;
-  HDEntryInfo          * parent;
+  HDWMEntryInfo          * parent;
   gboolean               active_found = FALSE;
 
-  g_debug ("In hn_app_switcher_real_changed_stack");
+  hd_wm_debug ("In hn_app_switcher_real_changed_stack");
 
   
-  if (!entry_info || !hd_entry_info_is_active (entry_info))
+  if (!entry_info || !hd_wm_entry_info_is_active (entry_info))
   {
     /* rebuild everything, since we were not told what has been topped
      * issue warning, as this is not how this function is meant to be
@@ -1016,16 +1016,16 @@ hn_app_switcher_changed_stack_cb (HDWM *hdwm, HDEntryInfo *entry_info, gpointer
     return;
   }
   
-  if (entry_info->type == HD_ENTRY_WATCHED_APP)
+  if (HD_WM_IS_APPLICATION (entry_info))
   {
     /* we only accept entries for windows and views */
-    g_warning ("Cannot handle HD_ENTRY_WATCHED_APP");
+    g_warning ("Cannot handle HD_ENTRY_APPLICATION");
     return;
   }
   
-  if (entry_info->type != HD_ENTRY_DESKTOP)  
+  if (!HD_WM_IS_DESKTOP (entry_info))
   {
-     parent = hd_entry_info_get_parent (entry_info);
+     parent = hd_wm_entry_info_get_parent (entry_info);
 
      if (!parent)
      {
@@ -1039,7 +1039,7 @@ hn_app_switcher_changed_stack_cb (HDWM *hdwm, HDEntryInfo *entry_info, gpointer
           l != NULL && pos < priv->nitems;
           l = l->next, pos++)
      {
-       HDEntryInfo *entry = l->data;
+       HDWMEntryInfo *entry = l->data;
           
        if (parent == entry)
        {
@@ -1060,7 +1060,7 @@ hn_app_switcher_changed_stack_cb (HDWM *hdwm, HDEntryInfo *entry_info, gpointer
     {
       GtkToggleButton *app_button;
 
-      g_debug ("Setting inconsistent state for pos %d", pos);
+      hd_wm_debug ("Setting inconsistent state for pos %d", pos);
 
       app_button = GTK_TOGGLE_BUTTON (priv->buttons[pos]);
       gtk_toggle_button_set_inconsistent (app_button, TRUE);
@@ -1086,7 +1086,7 @@ hn_app_switcher_finalize (GObject *gobject)
 
   g_object_unref (app_switch->hdwm);
 
-  g_debug ("Destroying HNAppSwitcher");
+  hd_wm_debug ("Destroying HNAppSwitcher");
 
   G_OBJECT_CLASS (hn_app_switcher_parent_class)->finalize (gobject);
 }
@@ -1099,13 +1099,13 @@ hn_app_switcher_constructor (GType                  type,
   GObject *object;
   HNAppSwitcher *appswitcher;
 
-  g_debug ("inside hn_app_switcher_constructor...");
+  hd_wm_debug ("inside hn_app_switcher_constructor...");
 
   
   object      = G_OBJECT_CLASS (hn_app_switcher_parent_class)->constructor (type,n_construct_params, construct_params);
   appswitcher = HN_APP_SWITCHER (object);
   
-  g_debug ("building HNAppSwitcher widget");
+  hd_wm_debug ("building HNAppSwitcher widget");
       
   hn_app_switcher_build (appswitcher);
 
@@ -1241,7 +1241,7 @@ hn_app_switcher_cad_kill_selected_items (GList *items)
       if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (item->button))
           && item->win != NULL)
         {
-          hd_wm_watched_window_attempt_signal_kill (item->win, SIGTERM, TRUE);
+          hd_wm_window_attempt_signal_kill (item->win, SIGTERM, TRUE);
         }
     }
 }
@@ -1300,7 +1300,7 @@ hn_app_switcher_close_application_dialog (HDWM *hdwm, HDWMCADAction action, GLis
 
   gtk_container_add (GTK_CONTAINER(hbox), label);
   gtk_container_add (GTK_CONTAINER(hbox), vbox);
-  g_debug ("there should be items %p", items);
+  hd_wm_debug ("there should be items %p", items);
   /* Collect open applications */
   for (l = items; l; l = l->next)
   {
@@ -1309,19 +1309,19 @@ hn_app_switcher_close_application_dialog (HDWM *hdwm, HDWMCADAction action, GLis
     GtkWidget *label;
     GdkPixbuf *icon = NULL;
     GtkIconTheme *icon_theme;
-    HDWMWatchableApp *app;
+    HDWMApplication *app;
     HDWMCADItem *item = (HDWMCADItem *) l->data;
-    g_debug ("item --> %p",l->data);
+    
     if (item->win == NULL)
       continue;
 
-    app = hd_wm_watched_window_get_app (item->win);
+    app = hd_wm_window_get_application (item->win);
       
     if (app == NULL)
       continue;
       
-    label = gtk_label_new (_(hd_wm_watchable_app_get_name (app)));
-    icon_name = hd_wm_watchable_app_get_icon_name(app);
+    label = gtk_label_new (_(hd_wm_application_get_name (app)));
+    icon_name = hd_wm_application_get_icon_name(app);
     icon_theme = gtk_icon_theme_get_default ();
     
     if (icon_name)
